@@ -7,7 +7,7 @@ from PyQt4 import QtGui
 import Image
 import code
 
-CURRENTVERSION = "0.2.6"
+CURRENTVERSION = "0.2-7"
 
 class MainWindow(QtGui.QMainWindow):
     def __init__(self):
@@ -19,7 +19,7 @@ class MainWindow(QtGui.QMainWindow):
 
         #Initial Settings
         self.resize(800,480)
-        self.setWindowTitle('London Tube Map 0.2.6')
+        self.setWindowTitle("London Tube Map " + CURRENTVERSION)
         
         #Open Image
         self.ChargerScene()
@@ -36,24 +36,27 @@ class MainWindow(QtGui.QMainWindow):
         abt = QtGui.QAction('About', self)
         fullsc.setShortcut('Ctrl+A')
         self.connect(abt, QtCore.SIGNAL('triggered()'), self.showAbout)
-        
-        #Alternative 
-        altImg = QtGui.QAction('Alternative ', self)
-        altImg.setShortcut('Ctrl+I')
-        self.connect(altImg, QtCore.SIGNAL('triggered()'), self.alternative)
+
         
         #Connect to Menu Bar
         menubar = self.menuBar()
         file = menubar.addMenu('&Fichier')
         file.addAction(fullsc)
-        file.addAction(altImg)
         file.addAction(abt)
         
         
         #About page
     def showAbout(self):
         aboutString = "London Tube Map: v" + CURRENTVERSION + "\nAmir Bendjazia (benjezzy@gmail.com)\nMaemo Forums: El Amir, \nTwitter: benjezzy \nMany thanks to everyone who helped! "
-        QtGui.QMessageBox.information(self, "About Tfl App", aboutString)
+        QtGui.QMessageBox.information(self, "About LTM: London Tube Map", aboutString)
+        
+    def fullscreen(self):
+        if not self.fullScreen :
+            self.showFullScreen()
+        else:
+            self.showNormal()
+
+        self.fullScreen = not (self.fullScreen)  
         
     def ChargerScene(self):
         #Load image
